@@ -267,7 +267,7 @@ template <class Type>
 struct per_term_info {
   // Input from R
   int blockCode;     // Code that defines structure
-  int blockSize;     // Size of one block 
+  int blockSize;     // Size of one block
   int blockReps;     // Repeat block number of times
   int blockNumTheta; // Parameter count per block
   matrix<Type> dist;
@@ -286,7 +286,7 @@ struct terms_t : vector<per_term_info<Type> > {
       int blockCode = (int) REAL(getListElement(y, "blockCode", &isNumericScalar))[0];
       int blockSize = (int) REAL(getListElement(y, "blockSize", &isNumericScalar))[0];
       int blockReps = (int) REAL(getListElement(y, "blockReps", &isNumericScalar))[0];
-      int blockNumTheta = (int) REAL(getListElement(y, "blockNumTheta", &isNumericScalar))[0];      
+      int blockNumTheta = (int) REAL(getListElement(y, "blockNumTheta", &isNumericScalar))[0];
       (*this)(i).blockCode = blockCode;
       (*this)(i).blockSize = blockSize;
       (*this)(i).blockReps = blockReps;
@@ -535,6 +535,7 @@ Type objective_function<Type>::operator() ()
   DATA_SPARSE_MATRIX(Zzi);
   DATA_MATRIX(Xd);
   DATA_VECTOR(yobs);
+  DATA_VECTOR(size); //only used in binomial
   DATA_VECTOR(weights);
   DATA_VECTOR(offset);
 
@@ -605,8 +606,8 @@ Type objective_function<Type>::operator() ()
         break;
       case binomial_family:
         s1 = logit_inverse_linkfun(eta(i), link); // logit(p)
-        tmp_loglik = dbinom_robust(yobs(i), weights(i), s1, true);
-        SIMULATE{yobs(i) = rbinom(weights(i), mu(i));}
+        tmp_loglik = dbinom_robust(yobs(i), size(i), s1, true);
+        SIMULATE{yobs(i) = rbinom(size(i), mu(i));}
         break;
       case Gamma_family:
         s1 = phi(i);           // shape
@@ -624,9 +625,9 @@ Type objective_function<Type>::operator() ()
       case betabinomial_family:
         s1 = mu(i)*phi(i); // s1 = mu(i) * mu(i) / phi(i);
         s2 = (Type(1)-mu(i))*phi(i); // phi(i) / mu(i);
-        tmp_loglik = glmmtmb::dbetabinom(yobs(i), s1, s2, weights(i), true);
+        tmp_loglik = glmmtmb::dbetabinom(yobs(i), s1, s2, size(i), true);
         SIMULATE {
-          yobs(i) = rbinom(weights(i), rbeta(s1, s2) );
+          yobs(i) = rbinom(size(i), rbeta(s1, s2) );
         }
         break;
       case nbinom1_family:
@@ -738,7 +739,7 @@ Type objective_function<Type>::operator() ()
         }
         SIMULATE{yobs(i) = yobs(i)*rbinom(Type(1), Type(1)-pz(i));}
       }
-
+      tmp_loglik *= weights(i);
       // Add up
       jnll -= keep(i) * tmp_loglik;
     }
